@@ -1,6 +1,6 @@
 ;;; elb-smie.el --- C major mode based on SMIE  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2015-2022  Free Software Foundation, Inc.
+;; Copyright (C) 2015-2023  Free Software Foundation, Inc.
 
 ;; Author: Stefan Monnier <monnier@iro.umontreal.ca>
 ;; Version: 1.1
@@ -16,7 +16,7 @@
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
+;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 
@@ -897,5 +897,14 @@ Past this column, we do not try to align the backslashes."
     (dotimes (_ 5)
       (indent-region (point-min) (point-max)))))
 
+(defun elb-font-lock-entry ()
+  (with-temp-buffer
+    (insert-file-contents (expand-file-name
+                           "../resources/xmenu.c" elb-bench-directory))
+    (elb-smie-mode)
+    (dotimes (_ 50)
+      (font-lock-flush)
+      (font-lock-ensure))))
+
 (provide 'elb-smie)
 ;;; elb-smie.el ends here
