@@ -1,10 +1,10 @@
 ;;; elisp-benchmarks.el --- elisp benchmarks collection -*- lexical-binding:t -*-
 
-;; Copyright (C) 2019-2022  Free Software Foundation, Inc.
+;; Copyright (C) 2019-2024  Free Software Foundation, Inc.
 
-;; Author: Andrea Corallo <akrl@sdf.org>
-;; Maintainer: Andrea Corallo <akrl@sdf.org>
-;; Version: 1.14
+;; Author: Andrea Corallo <acorallo@gnu.org>
+;; Maintainer: Andrea Corallo <acorallo@gnu.org>
+;; Version: 1.15
 ;; Keywords: languages, lisp
 ;; Package-Type: multi
 ;; Created: 2019-01-12
@@ -20,7 +20,7 @@
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
+;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 ;; In use for testing the Emacs Lisp implementation performance.
@@ -46,9 +46,12 @@
 (require 'benchmark)
 (require 'outline)
 (require 'org)
+(require 'bytecomp)
 (if (featurep 'native-compile)
     (require 'comp)
   (defvar native-comp-speed))
+(unless (boundp 'compilation-safety)
+  (defvar compilation-safety))
 
 (defgroup elb nil
   "Emacs Lisp benchmarks."
@@ -62,6 +65,10 @@
   "Default `native-comp-speed' to be used for native compiling the benchmarks."
   :type 'number)
 
+(defcustom elb-safety 0
+  "Default `compilation-safety' to be used for native compiling the benchmarks."
+  :type 'number)
+
 (defconst elb-bench-directory
   (expand-file-name "benchmarks/"
 	            (file-name-directory
@@ -93,6 +100,7 @@ RECOMPILE all the benchmark folder when non nil."
    (when current-prefix-arg
      (list (read-regexp "Run benchmark matching: "))))
   (let* ((native-comp-speed elb-speed)
+	 (compilation-safety elb-safety)
 	 (compile-function (if (featurep 'native-compile)
 			       #'native-compile
 			     #'byte-compile-file))
